==> zio-aws-robomaker_3-5.17.130.5-sources.jar: zio/aws/robomaker/model/DeleteSimulationApplicationRequest.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.robomaker.model.primitives.{Version, Arn}
import scala.jdk.CollectionConverters.*
final case class DeleteSimulationApplicationRequest(
    application: Arn,
    applicationVersion: Option[Version] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest = {
    import DeleteSimulationApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
      .builder()
      .application(Arn.unwrap(application): java.lang.String)
      .optionallyWith(
        applicationVersion.map(value => Version.unwrap(value): java.lang.String)
      )(_.applicationVersion)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly =
    zio.aws.robomaker.model.DeleteSimulationApplicationRequest
      .wrap(buildAwsValue())
}
object DeleteSimulationApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.DeleteSimulationApplicationRequest =
      zio.aws.robomaker.model.DeleteSimulationApplicationRequest(
        application,
        applicationVersion.map(value => value)
      )
    def application: Arn
    def applicationVersion: Option[Version]
    def getApplication: ZIO[Any, Nothing, Arn] = ZIO.succeed(application)
    def getApplicationVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("applicationVersion", applicationVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ) extends zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly {
    override val application: Arn =
      zio.aws.robomaker.model.primitives.Arn(impl.application())
    override val applicationVersion: Option[Version] = scala
      .Option(impl.applicationVersion())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ): zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-robomaker_3-6.20.78.1-sources.jar: zio/aws/robomaker/model/DeleteSimulationApplicationRequest.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.robomaker.model.primitives.{Version, Arn}
import scala.jdk.CollectionConverters.*
final case class DeleteSimulationApplicationRequest(
    application: Arn,
    applicationVersion: Optional[Version] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest = {
    import DeleteSimulationApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
      .builder()
      .application(Arn.unwrap(application): java.lang.String)
      .optionallyWith(
        applicationVersion.map(value => Version.unwrap(value): java.lang.String)
      )(_.applicationVersion)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly =
    zio.aws.robomaker.model.DeleteSimulationApplicationRequest
      .wrap(buildAwsValue())
}
object DeleteSimulationApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.DeleteSimulationApplicationRequest =
      zio.aws.robomaker.model.DeleteSimulationApplicationRequest(
        application,
        applicationVersion.map(value => value)
      )
    def application: Arn
    def applicationVersion: Optional[Version]
    def getApplication: ZIO[Any, Nothing, Arn] = ZIO.succeed(application)
    def getApplicationVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("applicationVersion", applicationVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ) extends zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly {
    override val application: Arn =
      zio.aws.robomaker.model.primitives.Arn(impl.application())
    override val applicationVersion: Optional[Version] = zio.aws.core.internal
      .optionalFromNullable(impl.applicationVersion())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.DeleteSimulationApplicationRequest
  ): zio.aws.robomaker.model.DeleteSimulationApplicationRequest.ReadOnly =
    new Wrapper(impl)
}
